@@ -882,6 +882,8 @@ class MotofitMainWindow(QtWidgets.QMainWindow):
         if isinstance(host, StructureNode) and idx in [0, len(host._data) - 1]:
             return msg("You can't remove the fronting or backing media")
 
+        # TODO: unlink any parameters that might depend on this component?
+
         # all checking done, remove a layer
         host.remove_component(idx)
 
@@ -1056,8 +1058,14 @@ class MotofitMainWindow(QtWidgets.QMainWindow):
                 # user probably aborted the fit
                 # but it's still worth creating a fit curve, so don't return
                 # in this catch block
-                msg(repr(e))
-                print(repr(e))
+                # xk should be the best fit so far.
+                text = e.args[0]
+                xk = e.args[1]
+
+                msg(repr(text))
+                print(repr(text))
+
+                objective.setp(xk)
                 print(objective)
             except Exception as e:
                 # Typically shown when sensible limits weren't provided
@@ -1566,14 +1574,28 @@ class MotofitMainWindow(QtWidgets.QMainWindow):
 
         # only redraw if you're altering values
         # otherwise we'd be performing continual updates of the model
-        if top_left.column() != 1:
-            return
+        if (top_left.column() == 1 and isinstance(node, ParNode) and
+                len(role) and role[0] == QtCore.Qt.EditRole):
+            param = node.parameter
+            wipe_update = [find_data_object(top_left).data_object]
 
-        hierarchy = node.hierarchy()
-        for n in hierarchy:
-            if isinstance(n, DataObjectNode):
-                self.clear_data_object_uncertainties([n.data_object])
-                self.update_gui_model([n.data_object])
+            # find if there are dependent parameters on the original
+            # parameter. There's an argument for doing this in the treeModel,
+            # the model is normally responsible for manipulating data. However,
+            # if we do it here then we only need to redraw once.
+            ds = self.treeModel.datastore
+            for do in ds:
+                model = do.model
+                cpars = model.parameters.constrained_parameters()
+                for cpar in cpars:
+                    deps = cpar.dependencies()
+                    if param in deps:
+                        wipe_update.append(do)
+                        break
+
+            wipe_update = list(unique(wipe_update))
+            self.clear_data_object_uncertainties(wipe_update)
+            self.update_gui_model(wipe_update)
 
     def calculate_chi2(self, data_objects):
         # calculate chi2 for all the data objects
@@ -1653,6 +1675,7 @@ class ProgressCallback(QtWidgets.QDialog):
         self.ui.timer.display(float(self.elapsed))
         self.ui.buttonBox.rejected.connect(self.abort)
         self.objective = objective
+        self.iterations = 0
 
     def abort(self):
         self.abort_flag = True
@@ -1661,6 +1684,8 @@ class ProgressCallback(QtWidgets.QDialog):
         # a callback for scipy.optimize.minimize, which enters
         # every iteration.
         new_time = time.time()
+        self.iterations += 1
+
         if new_time - self.last_time > 1:
             # gp = self.dataset.graph_properties
             # if gp.line2Dfit is not None:
@@ -1672,11 +1697,14 @@ class ProgressCallback(QtWidgets.QDialog):
             self.ui.timer.display(float(self.elapsed))
             self.last_time = new_time
 
-            text = 'Chi2 : %f' % self.objective.chisqr(xk)
+            text = 'Chi2 : {}\nIterations : {}'.format(
+                self.objective.chisqr(xk),
+                self.iterations)
+
             self.ui.values.setPlainText(text)
             QtWidgets.QApplication.processEvents()
             if self.abort_flag:
-                raise RuntimeError("WARNING: FIT WAS TERMINATED EARLY")
+                raise RuntimeError("WARNING: FIT WAS TERMINATED EARLY", xk)
 
         return self.abort_flag
 
