@@ -1,8 +1,8 @@
 import numpy as np
 
 
-TINY = np.finfo(np.float64).tiny
-
+# TINY = np.finfo(np.float64).tiny
+TINY = 1e-30
 
 """
 import numpy as np
@@ -13,6 +13,18 @@ w = np.array([[0, 2.07, 0, 0],
               [0, 6.36, 0, 3]])
 """
 
+"""
+The timings for the reflectivity calculation above are (6/3/2019):
+
+_creflect.abeles = 254 us
+_reflect.abeles = 433 us
+the alternative cython implementation is 572 us.
+
+If TINY is made too small, then the C implementations start too suffer because
+the sqrt calculation takes too long. The C implementation is only just ahead of
+the python implementation!
+"""
+
 
 def abeles(q, layers, scale=1., bkg=0, threads=0):
     """
